
variable "data_center" {}
variable "cluster" {}
variable "workload_datastore" {}
variable "compute_pool" {}
variable "admin_password" {}
variable "join_domain" {}
variable "domain_admin_user" {}
variable "domain_admin_password" {}

data "vsphere_datacenter" "dc" {
  name                      = var.data_center
}
data "vsphere_compute_cluster" "cluster" {
  name                      = var.cluster
  datacenter_id             = data.vsphere_datacenter.dc.id
}
data "vsphere_datastore" "datastore" {
  name                      = var.workload_datastore
  datacenter_id             = data.vsphere_datacenter.dc.id
}

data "vsphere_resource_pool" "pool" {
  name                      = var.compute_pool
  datacenter_id             = data.vsphere_datacenter.dc.id
}

data "vsphere_network" "network" {
  name                      = "SDDC-UKB-Core_Network"
  datacenter_id             = data.vsphere_datacenter.dc.id
}
data "vsphere_virtual_machine" "vm_template" {
  name                      = "WinServer-2016-Template"
  datacenter_id             = data.vsphere_datacenter.dc.id
}

# ================================================

resource "vsphere_virtual_machine" "vm1" {
  count                     = "1"
  name                      = "terra-testVM-${count.index + 1}"
  resource_pool_id          = data.vsphere_resource_pool.pool.id
  datastore_id              = data.vsphere_datastore.datastore.id
  folder                    = "Workloads"
  num_cpus                  = 2
  memory                    = 4096
  guest_id                  = "windows9Server64Guest"

  scsi_type                 = data.vsphere_virtual_machine.vm_template.scsi_type

  network_interface {
    network_id              = data.vsphere_network.network.id
  }

  disk {
    label                   = "disk0"
    size                    = 80
  }
  disk {
    label                   = "disk1"
    size                    = 80
	  unit_number             = 1
  }
  
  clone {
    template_uuid           = data.vsphere_virtual_machine.vm_template.id
        
    customize {
       windows_options{
         computer_name         = "terra-testVM-${count.index + 1}"
         admin_password        = var.admin_password
         join_domain           = var.join_domain
         domain_admin_user     = var.domain_admin_user
         domain_admin_password = var.domain_admin_password
          auto_logon           = "true"
          auto_logon_count     = "5"
          run_once_command_list= [
           #"winrm quickconfig -force",
           #"winrm set winrm/config @{MaxEnvelopeSizekb=\"100000\"}",
           #"winrm set winrm/config/Service @{AllowUnencrypted=\"true\"}",
           #"winrm set winrm/config/Service/Auth @{Basic=\"true\"}",
          ]
    }
    network_interface {
      ipv4_address          = "172.29.0.${80 + count.index}"
      ipv4_netmask          = 24
      dns_server_list       = ["172.25.1.35", "172.25.1.71"]
    }
    ipv4_gateway            = "172.29.0.1"
    }
  }
}
